% This example shows the drawbubble function set to draw a force-directed
% layout with a legend.

% The list of nodes is contained in a cell array. Information for each node
% is contained within its own cell array. The order of the nodes is not important.
nodes = {{'scallion', 10, 1}, {'garlic', 30, 1}, {'tomato', 15, 1}, {'sesame oil', 8, 2}, {'olive oil', 15, 2}, {'soy sauce', 9, 2}, {'starch', 2, 2}, {'sake', 2, 3}, {'white wine', 2, 3}, {'shrimp', 2, 4}, {'mussel', 1, 4}, {'parsley', 9, 5}, {'parmesan cheese', 3, 6}, {'mozzarella cheese', 2, 6}, {'nut', 1, 7}, {'black pepper', 15, 8}};

% The list of links is contained in a cell array. Information for each link
% is contained within its own cell array. The source, target, and strength
% of each link occupy the first, second, and third positions of each link's
% cell array, respectively. Each source and target references the cell
% array containing the nodes as if it were zero-based. The order of the
% links is not important.
links = {{0, 1, 2}, {1, 3, 2}, {1, 7, 2}, {1, 9, 2}, {1, 8, 2}, {1, 10, 2}, {1, 13, 2}, {1, 2, 2}, {1, 11, 2}, {1, 14, 2}, {1, 12, 2}, {1, 15, 2}, {9, 7, 4}, {9, 8, 8}, {9, 13, 12}, {9, 2, 8}, {9, 12, 12}, {9, 11, 2}, {9, 5, 2}, {7, 10, 2}, {7, 8, 8}, {7, 13, 5}, {7, 2, 4}, {7, 12, 5}, {7, 11, 2}, {5, 13, 2}, {5, 8, 2}, {5, 2, 2}, {5, 12, 2}, {8, 10, 4}, {8, 4, 2}, {8, 13, 20}, {8, 15, 4}, {8, 2, 16}, {8, 14, 2}, {8, 3, 2}, {8, 11, 4}, {8, 12, 25}, {10, 4, 2}, {10, 15, 2}, {10, 13, 4}, {10, 12, 5}, {10, 9, 2}, {13, 4, 2}, {13, 15, 2}, {13, 14, 2}, {13, 3, 2}, {13, 11, 2}, {13, 12, 35}, {4, 2, 2}, {4, 12, 2}, {15, 14, 2}, {15, 11, 4}, {15, 12, 4}, {2, 13, 15}, {2, 10, 2}, {2, 15, 4}, {2, 12, 18}, {14, 2, 2}, {14, 9, 2}, {14, 12, 2}, {14, 11, 2}, {14, 3, 2}, {11, 12, 4}, {11, 2, 4}, {11, 3, 2}, {3, 2, 2}, {3, 9, 2}, {3, 12, 2}};

% The drawbubble function requires a set of parameters. Here, 'c' is set 
% to equal 'config', a class containing default values for all the 
% parameters. The properties of 'c' are then set to specify the nature of
% the visualization. See config.m for the default values and more information on
% each parameter.

c = config;
c.name = 1; % Numeric, specifies that the name of each node is the first element of each cell in the list of nodes.
c.size = 2; % Numeric, specifies that the size of each node is the second element of each cell in the list of nodes.
c.group = 3; % Numeric, specifies that the group of each node is the third element of each cell in the list of nodes.
c.linkstrength = 1; % Boolean, tells the drawbubble function to draw each link's width according to its strength.
c.nodetext = 1; % Boolean, tells the drawbubble function to label each node with its name.
c.textcolor = 'red'; % String, specifies the color of the label text. Can be an SVG named color, rgb() or rgba() color code.  
c.nodecolor = 'rgba(50, 100, 150, 1)'; % String, specifies the color of the nodes. Can be an SVG named color, rgb() or rgba() color code.
c.linkscolor = 'rgba(10, 30, 30, 0.5)'; % String, specifies the color of the links. Can be an SVG named color, rgb() or rgba() color code.
c.legendtext1 = 'Prevalence'; % String, specifies the text over the node portion of the legend.
c.legendtext2 = 'Shared compounds'; % String, specifies the text over the link portion of the legend.
c.legend = 1; % Boolean, include the legend or not.

% The nodes, links, and the configuration parameters are passed to the
% drawbubbles function. 'openhtml' specifies that the figure will be opened
% and presented in html format.

drawbubbles(nodes, links, c, 'openhtml'); % Generates the figure.