% This example shows the drawbubble function set to draw a force-directed,
% edge bundled figure with an image underneath. The user must supply
% information about an image in order for one to be included.

% The list of nodes is contained in a cell array. Information for each node
% is contained within its own cell array. The order of the nodes is not important.
nodes = {{0, 0}, {10, 20}, {40, -10}, {-50, 60}};

% The list of nodes is contained in a cell array. Information for each node
% is contained within its own cell array. The source, target, and strength
% of each link go in the first, second, and third positions of each link's
% cell array, respectively. Each source and target references the cell
% array containing the nodes as if it were zero-based. The order of the
% links is not important.
links = {{0, 1, 2}, {1, 2, 1}, {2, 3, 3}, {3, 0, 1}};

% The drawbubble function requires a set of parameters. Here, 'c' is set 
% to equal 'config', a class containing default values for all the 
% parameters. The properties of 'c' are then set to specify the nature of
% the visualization. See config.m for the default values and more information on
% each parameter.

c = config;
c.x = 1; % Numeric, specifies that the x-coordinate of each node is the first element of each cell in the list of nodes. 
c.y = 2; % Numeric, specifies that the y-coordinate of each node is the second element of each cell in the list of nodes.
c.linkstrength = 1; % Boolean, tells the drawbubble function to draw each link's width according to its strength.
c.linkwidth = 2; % Numeric, specifies the width of each link if linkstrength is 0.
c.nodecolor = 'rgba(100, 150, 200, 0.6)'; % String, specifies the color of the nodes. Can be an SVG named color, rgb() or rgba() color code.
c.linkscolor = 'rgba(10, 30, 30, 0.5)'; % String, specifies the color of the links. Can be an SVG named color, rgb() or rgba() color code.
c.forcedirected = 0; % Boolean, force-direct the layout or not.
c.edgebundling = 1; % Boolean, bundle the edges or not.
c.cycles = 10; % Numeric, the number of cycles to run the edge bundling algorithm for.
c.iterations = 100; % Numeric, the number of iterations of movement per cycles.
c.stepsize = 2; % Numeric, the distance each control point moves per iteration.
c.nodesize = 5; % Numeric, the size of each node. Set to 0 for a figure without nodes.
c.image = 1; % Boolean, include an underlying image or not. 
c.imagepath = '/Users/Username/Documents/MATLAB/2DBrain.tif'; % String, set path to image here. 
c.imageheight = 960; % Numeric, the height, in pixels, of the image.
c.imagewidth = 1427; % Numeric, the width, in pixels, of the image.

% These values may require transposition depending on the coordinate system
% used for the brain.
c.xMin = -101; % The lowest possible x-value in the dataset.
c.xMax = 67; % The highest possible x-value in the dataset.
c.yMin = -42; % The lowest possible y-value in the dataset.
c.yMax = 75; % The highest possible y-value in the dataset.

% The nodes, links, and the configuration parameters are passed to the
% drawbubbles function. 'openhtml' specifies that the figure will be opened
% and presented in html format.

drawbubbles(nodes, links, c, 'openhtml');