classdef config
   properties
   % Information:
   % Values are used to indicate the position of the data in the cell array
   % for each node/link. A value of zero means that the information will not be
   % used.
   x = 0; % X-coordinates for each node.
   y = 0; % Y-coordinates for each node.
   name = 0; % Names for each node.
   size = 0; % Areas for each node.
   group = 0; % Grouping for each node.
   linkstrength = 0; % Value corresponding to each link's strength.
   
   % Presentation:
   % Values that control the visual representation of the data.
   drawnodes = 1; % Boolean, draw nodes or not.
    nodetext = 0; % Boolean, label each node with its name or not.
    textcolor = 'black'; % Color of text appended to nodes.
    nodesize = 5; % Radius of each node if size is 0.
    nodesizemin = 0; % Specify minimum node size (zero defaults to a preset value)
    nodesizemax = 0; % Specify maximum node size (zero defulats to a preset value)
    nodecolor = 'blue'; % Array containing one or more colors to be assigned to each node based on group or size.
    fixed = 0; % Whether or not the nodes are fixed in place.
   drawlinks = 1; % Boolean, draw links or not.
    linkscolor = 'rgba(10, 30, 30, 0.5)'; % Color of links.
    linkwidth = 2; % Width of links if linkstrength is 0.
    drawarrows = 0; % Whether or not to include arrows indicating the directionality of the links.
    arrowsize = 10; % Larger value yields smaller arrows.
    arrowcolor = 'rgba(100, 100, 250, 0.5)' % Controls the color of the arrows.
    forcedirected = 1; % Boolean, to drive the layout using force-direction or not.
   edgebundling = 0; % Boolean, bundle edges or not. Greater values for cycles, iterations, and stepsize result in higher degrees of bundling, but require more time for the visualization to be produced. Algorithm based on Danny Holten's work described in http://www.win.tue.nl/~dholten/papers/forcebundles_eurovis.pdf.
    cycles = 1; % Number of cycles to run the bundling algorithm. A reasonable value might be between 5 and 10.
    iterations = 1; % Number of iterations to perform per cycle. A reasonable value might be between 20 and 100.
    stepsize = 1; % Amount of control point movement per iteration. A reasonable value might be between 0.5 and 5.
   legend = 0; % Include legend or not.
    legendtext1 = ''; % Label for the circle size portion of the legend.
    legendtext2 = ''; % Label for the link width portion of the legend.
   image = 0; % Boolean, to have an underlying image or not.
    imagepath = ''; % The file path of the image.
    imageheight = 0; % The height, in pixels, of the image.
    imagewidth = 0; % The width, in pixels, of the image.
    
    % These values may require transposition depending on the coordinate system used.
    xMin = 0; % The lowest possible x-value in the dataset.
    xMax = 0; % The highest possible x-value in the dataset.
    yMin = 0; % The lowest possible y-value in the dataset.
    yMax = 0; % The highest possible y-value in the dataset.
    
   end
end
