% ask user what kind of visualization they want
% ask for necessary data
% run visualization code

fprintf('Common variable names such as cortex and tala may be overwritten by this script.\nIf you wish to preserve these variables it is recommended that they be renamed or stored elsewhere.\nSee DVP & activateBrain/README.txt for help getting started.');
visualizationType = input('What kind of visualization do you want? (''activateBrain'' | ''DVP'' (only works if Safari is installed) | ''arrows''): ');

switch visualizationType
    case 'activateBrain'
        viztype = '3D';
        
        cOrtex.Verts = input('Enter the variable containing the vertices of the cortex (type ''help'' to see the proper variable structure): ');
        while isa(cOrtex.Verts, 'char')
            fprintf('The vertices of the cortex should be contained in an M by 3 array, where M is the number of vertices.\nEach row should contain the 3D coordinates of a vertex.\nFor an example, type load(''MNI_brain.mat'', ''cortex''); into the console and view cortex.vert in the variable editor.\n');
            cOrtex.Verts = input('Enter the variable containing the vertices of the cortex (type ''help'' for help): ');
        end
        
        cOrtex.Tris = input('Enter the variable containing the triangles of the cortex (type ''help'' to see the proper variable structure): ');
        while isa(cOrtex.Tris, 'char')
            fprintf('The tessellations should be contained in an M by 3 array, where M is the number of triangles forming the cortical surface.\nEach row should contain 3 integers referencing the vertices that will form the points of a single triangle.\nFor an example, type load(''MNI_brain.mat'', ''cortex''); into the console and view cortex.tri in the variable editor.\n');
            cOrtex.Tris = input('Enter the variable containing the triangles of the cortex (type ''help'' to see the proper variable structure): ');
        end
        
        eLectrode.Coords = input('Enter the variable containing the coordinates for the unprojected electrodes (type ''help'' for help): ');
        while isa(eLectrode.Coords, 'char')
            fprintf('The 3D coordinates of the electrode location should be contained in an M by 3 array, where M is the number of electrodes\nEach row should contain a set of coordinates for a single electrode.\nFor an example, type load(''MNI_brain.mat'', ''tala''); into the console and view tala.electrodes in the variable editor.\n');
            eLectrode.Coords = input('Enter the variable containing the coordinates for the unprojected electrodes (type ''help'' for help): ');            
        end
        noActivations = zeros(size(eLectrode.Coords, 1), 1);
        
        eLectrode.Acts = input('Enter the variable containing the activations for the electrodes (if there are no activations, type noActivations,  type ''help'' for help): ');
        while isa(eLectrode.Acts, 'char')
            fprintf('The activations for the electrodes should be contained in an M by 1 array, where M is the number of electrodes\nEach row should contain an activation value.\nFor an example, type load(''MNI_brain.mat'', ''tala''); into the console and view tala.activations in the variable editor.\n');
            eLectrode.Acts = input('Enter the variable containing the coordinates for the unprojected electrodes (if there are no activations, type noActivations, type ''help'' for help): ');            
        end
        
        cortex.vert = cOrtex.Verts;
        cortex.tri = cOrtex.Tris;
        tala.electrodes = eLectrode.Coords;
        tala.activations = eLectrode.Acts;
        script1;
        
    case 'DVP'
        viztype = '2D';
        script1;
        
    case 'arrows'
        load('MNI_brain.mat', 'cmapstruct'); % sets the color map
        
        cortexVerts = input('Enter the variable containing the vertices of the cortex (type ''help'' to see the proper variable structure): ');
        while isa(cortexVerts, 'char')
            fprintf('The vertices of the cortex should be contained in an M by 3 array, where M is the number of vertices.\nEach row should contain the 3D coordinates of a vertex.\nFor an example, type load(''MNI_brain.mat'', ''cortex''); into the console and view cortex.vert in the variable editor.\n');
            cortexVerts = input('Enter the variable containing the vertices of the cortex (type ''help'' for help): ');
        end
        
        cortexTris = input('Enter the variable containing the triangles of the cortex (type ''help'' to see the proper variable structure): ');
        while isa(cortexTris, 'char')
            fprintf('The tessellations should be contained in an M by 3 array, where M is the number of triangles forming the cortical surface.\nEach row should contain 3 integers referencing the vertices that will form the points of a single triangle.\nFor an example, type load(''MNI_brain.mat'', ''cortex''); into the console and view cortex.tri in the variable editor.\n');
            cortexTris = input('Enter the variable containing the triangles of the cortex (type ''help'' to see the proper variable structure): ');
        end
        
        electrodeCoords = input('Enter the variable containing the coordinates for the unprojected electrodes (type ''help'' for help): ');
        while isa(electrodeCoords, 'char')
            fprintf('The 3D coordinates of the electrode location should be contained in an M by 3 array, where M is the number of electrodes\nEach row should contain a set of coordinates for a single electrode.\nFor an example, type load(''MNI_brain.mat'', ''tala''); into the console and view tala.electrodes in the variable editor.\n');
            electrodeCoords = input('Enter the variable containing the coordinates for the unprojected electrodes (type ''help'' for help): ');            
        end
        
        cortex.vert = cortexVerts;
        cortex.tri = cortexTris;
        tala.electrodes = electrodeCoords;
        
        brainStruct.vcontribs = electrodesContributions(cortex, tala, 'linear', 10, 10); 
        
        viewstruct.what2view = {'brain'};
        viewstruct.viewvect = [120, 10];
        viewstruct.material = 'dull';
        viewstruct.enablelight = 1;
        viewstruct.enableaxis = 0;
        viewstruct.lightpos = [200, 0, 0];
        viewstruct.lightingtype = 'gouraud';
        brainStruct.viewstruct = viewstruct;
        
        brainStruct.cmapstruct = cmapstruct;
        brainStruct.cortex = cortex;
        brainStruct.tala = tala;
        
        reductionDistance = input('At what distance should arrows be combined? (0 for no combination, greater for more combination): ');
        bundle = input('Use force-directed edge bundling? (1 | 0): ');
        project = input('Project arrows onto cortex? (1 | 0): ');
        
        plotDifferentArrows(brainStruct, project, bundle, reductionDistance);
        
end