clear variables;
close all;

load r2_high
load r2_low

activation = r2_low;
activation = (activation-min(activation))/(max(activation)-min(activation));

activation(find(activation > 0.80)) = 0.80;
activation(find(activation < 0.10)) = 0.10;

activation = (activation-min(activation))/(max(activation)-min(activation));
activation = 1*activation;
%%

current_path = cd; 
if isunix 
    path_seperator = '/';
else
    path_seperator = '\';
end


addpath ([current_path,path_seperator,'activeBrain']);
addpath ([current_path,path_seperator,'activeBrain/geometry']);
addpath ([current_path,path_seperator,'activeBrain/transformModel']);
addpath ([current_path,path_seperator,'activeBrain/demo']);

opengl neverselect;
load talairach.mat
%load the SUMA talairach brain:
load pial_talairach;
%this creates a variable cortex

%make the model coarser:
cortexcoarser = coarserModel(cortex, 10000);
origin = [0 20 40];
smoothrad = 25;
mult = 0.5;
[cortexsmoothed] = smoothModel(cortexcoarser, smoothrad, origin, mult);
cortex = hullModel(cortexsmoothed);
tala.electrodes = talairach;
% 
% %% Projecting the electrodes
normdist = 40;
[ tala ] = projectElectrodes( cortex, tala, normdist);

%% Computing the electrode contributions
%reload the original SUMA talairach brain:
load pial_talairach;

%compute the contributions of the given electrodes:
kernel = 'linear';
param = 10;
cutoff = 10;
[ vcontribs ] = electrodesContributions( cortex, tala, kernel, param, cutoff);
save vcontribs
% load vcontribs_test vcontribs;
%% Visualizing the activations
%viewstruct.what2view = {'brain', 'activations','electrodes'};
viewstruct.what2view = {'brain', 'activations'};
viewstruct.viewvect = [270, 0];
viewstruct.material = 'dull';
viewstruct.enablelight = 1;
viewstruct.enableaxis = 0;
viewstruct.lightpos = [-170, 0, 0];
viewstruct.lightingtype = 'gouraud';

%and how you want to see it:
%cmapstruct.cmap = colormap('Jet'); close(gcf); %because colormap creates a figure

% yellow-red
% cmapstruct.cmap = zeros(256,3);
% cmapstruct.cmap(:,1) = 1;
% cmapstruct.cmap(:,2) = 1:-1/256:1/256;
% cmapstruct.cmap(:,3) = 0;
% cmapstruct.cmap      = log(cmapstruct.cmap + 1) ./ log(2);

% cyan-blue
% cmapstruct.cmap = zeros(256,3);
% cmapstruct.cmap(:,1) = 0;
% cmapstruct.cmap(:,2) = 1:-1/256:1/256;
% cmapstruct.cmap(:,3) = 1;
% cmapstruct.cmap      = log(cmapstruct.cmap + 1) ./ log(2);

% blue-red
cmapstruct.cmap = zeros(512,3);
cmapstruct.cmap(1:256,1) = 1;
cmapstruct.cmap(1:256,2) = 1/256:1/256:1;
cmapstruct.cmap(1:256,3) = 0;
cmapstruct.cmap(257:512,1) = 0;
cmapstruct.cmap(257:512,2) = 1:-1/256:1/256;
cmapstruct.cmap(257:512,3) = 1;
cmapstruct.cmap      = log(cmapstruct.cmap + 1) ./ log(2);



cmapstruct.basecol = [0.7, 0.7, 0.7];
cmapstruct.fading = true;
%cmapstruct.ixg2 = floor(length(cmapstruct.cmap) * 0.15);
%cmapstruct.ixg1 = -cmapstruct.ixg2;
cmapstruct.ixg2 = 256+64;
cmapstruct.ixg1 = 256-64;
cmapstruct.enablecolormap = true;
cmapstruct.enablecolorbar = true;

%Run |activateBrain|:
%NOTE:
%Do not forget to use the same brain model as the one used for the
%precomputation of the contributions (that is, the fine one). Also,
%use the subj that is the output of |projectElectrodes|).
ix = 1;
for idx_ica = 1 : size(activation,1);
    
        tala.activations = activation(idx_ica,:)';
%        cmapstruct.cmin = min(tala.activations);
%        cmapstruct.cmax = max(tala.activations);
        cmapstruct.cmin = -1;
        cmapstruct.cmax = 1;
        clf reset; set(gca, 'Color', 'none'); set(gcf, 'Color', 'w'); grid off;
        activateBrain( cortex, vcontribs, tala, ix, cmapstruct, viewstruct );
        
end


set(gcf,'PaperPosition',[0,0,11,5]);
set(gcf,'PaperSize',[11,5]);
print('-painters','-r300','-dpng','low.png');


% %%
% 
% clear grad;
% 
% %szfile = '/Users/pbrunner/Documents/bird-server/Peter Brunner/work/doku/epilepsy_and_behaviour_paper_2008/figures/color_gradient_red_yellow.png';
% szfile = '/Users/pbrunner/Documents/bird-server/Peter Brunner/work/doku/epilepsy_and_behaviour_paper_2008/figures/color_gradient_blue_cyan.png';
% 
% I = imread(szfile);
% 
% for i=1:256
%   grad(1,i,1)=0;
%   grad(1,i,2)=(i-1);
%   grad(1,i,3)=256;
% end
% 
% image(uint8(grad));
