function plotDifferentArrows(brainStruct, projected, bundled, reductionDistance)

opengl neverselect

sTart.Coords = input('Enter the variable containing the start coordinates (type ''help'' for help): ');
while isa(sTart.Coords, 'char')
    fprintf('The start coordinates for the arrows should be contained in an M by 3 array, where M is the number of arrows.\nEach row should contain a set of coordinates for a single arrow start point.\nFor an example, type load(''ArrowsGrangerCausality_TheWall1_Task_HighGamma@10Hz_ARModel-Order10_pval-0.05_bfc.mat'', ''coorStart''); into the console and view coorStart in the variable editor.\n');
    sTart.Coords = input('Enter the variable containing the coordinates for the unprojected electrodes (type ''help'' for help): ');            
end

eNd.Coords = input('Enter the variable containing the end coordinates (type ''help'' for help): ');
while isa(eNd.Coords, 'char')
    fprintf('The end coordinates of the arrows should be contained in an M by 3 array, where M is the number of arrows.\nEach row should contain a set of coordinates for a single arrow endpoint.\nFor an example, type load(''ArrowsGrangerCausality_TheWall1_Task_HighGamma@10Hz_ARModel-Order10_pval-0.05_bfc.mat'', ''coorEnd''); into the console and view coorEnd in the variable editor.\n');
    eNd.Coords = input('Enter the variable containing the coordinates for the unprojected electrodes (type ''help'' for help): ');            
end

pvAls = input('Enter the variable containing the thickness of the arrows (type ''help'' for help): ');
while isa(pvAls, 'char')
    fprintf('The thicknesses should be contained in an M by 1 array, where M is the number of arrows.\nEach row should contain a p-value for a single arrow.\nFor an example, type load(''ArrowsGrangerCausality_TheWall1_Task_HighGamma@10Hz_ARModel-Order10_pval-0.05_bfc.mat'', ''pv''); into the console and view pv in the variable editor.\n');
    pvAls = input('Enter the variable containing the thickness of the arrows (type ''help'' for help): ');            
end


coorStart = sTart.Coords;
coorEnd = eNd.Coords;
pv = pvAls;

brainStruct.ix = 1;
brainStruct.viewstruct.what2view = {'brain'};
brainStruct.cmapstruct.enablecolorbar = 0;
brainStruct.viewstruct.viewvect = [-90 0];
brainStruct.viewstruct.lightpos = [-200,0,0];

%Sorts causality strengths
[p_sorted,p_sorted_index] = sort(pv);
noarrows = length(pv);

%Finds distances between each start and end coordinate
for idxA=1:noarrows,
    for idxB=1:noarrows,
        d_start(idxA,idxB) = sqrt(sum(coorStart(idxA,:) - coorStart(idxB,:)).^2);

        d_end(idxA,idxB)   = sqrt(sum(coorEnd(idxA,:) - coorEnd(idxB,:)).^2);
        
    end
end

%When the distances between starts and ends of a pair of arrows are both
%less than K they are considered duplicates
K = reductionDistance;
duplicates = double(d_start < K & d_end < K);
%surf(duplicates), view(2), axis tight;

%Identifies true duplicates (does not include "duplicates" that are the same arrow twice) 
list_remove = [];
for idx=1:noarrows,
    
    index = setdiff(find(duplicates(idx,:)),idx);
    
    if ~isempty(index),
        
        %Location of the duplicate
        set_index = [idx;index(:)];
        
        %Orders p-values for each duplicate
        [p_set,p_set_index] = sort(pv(set_index));        
        
        %Adds to list_remove all of the duplicates but the one with the
        %highest p-value
        list_remove = [list_remove;set_index(p_set_index(2:end))];
        
    end
    
end

for idx=1:noarrows,
    d(idx) = sqrt(sum((coorStart(idx,:)-coorEnd(idx,:)).^2));
end

list_remove = [list_remove;find(d(:) < K)];

ind = setdiff(p_sorted_index,unique(list_remove));
coorStart = coorStart(ind,:);
coorEnd = coorEnd(ind,:);
pv = pv(ind);

[p_sorted,p_sorted_index] = sort(pv);

ind = p_sorted_index(p_sorted_index(end:-1:1));
coorStart = coorStart(ind,:);
coorEnd = coorEnd(ind,:);
pv = pv(ind);

%Transforms coordinates (why?)
% coorStart(:,3) = coorStart(:,3) - 6;
% coorEnd(:,3) = coorEnd(:,3) - 6;
% coorStart(:,1) = coorStart(:,1) - 3;
% coorEnd(:,1) = coorEnd(:,1) - 3;

if projected

    %Make the model coarser:
    cortexcoarser = coarserModel(brainStruct.cortex, 50000);

    %Compute the convex hull:
    cortex_convex = hullModel(cortexcoarser);
    %This deprives the brain model of the sulci

    brainStruct.cortexHull = cortex_convex;

elseif ~projected
    
    brainStruct.cortexHull = brainStruct.cortex;
    
end
    
ArSzLt = [1 2];
id = pv == 0;
pv(id) = 1e-30;
pv = -log10(pv);
%Plots brain and arrows
plotArrows(brainStruct, coorStart, coorEnd, pv, ArSzLt, projected, bundled);
%Plots balls for electrodes
plotBalls(coorStart, 'r', 1.5); plotBalls(coorEnd, 'r', 1.5); 

fprintf('Done');
      