clear all
close all

opengl neverselect

addpath('./activeplot');
addpath('./activeplot/activeBrain');
addpath('./export_fig');
name = 'ArrowsGrangerCausality_TheWall1_Task_HighGamma@10Hz_ARModel-Order10_pval-0.05_bfc.mat';
load(name);

% Load MNI brain
load('MNI_brain.mat');
brainStruct.vcontribs = vcontribs;
brainStruct.viewstruct = viewstruct;
brainStruct.cmapstruct = cmapstruct;
brainStruct.cortex = cortex;
brainStruct.tala = tala;
brainStruct.ix = 1;
brainStruct.viewstruct.what2view = {'brain'};
brainStruct.cmapstruct.enablecolorbar = 0;
brainStruct.viewstruct.viewvect = [-90 0];
brainStruct.viewstruct.lightpos = [-200,0,0];

%Sorts causality strengths
[p_sorted,p_sorted_index] = sort(pv);
noarrows = length(pv);

%Finds distances between each start and end coordinate
for idxA=1:noarrows,
    for idxB=1:noarrows,
        d_start(idxA,idxB) = sqrt(sum(coorStart(idxA,:) - coorStart(idxB,:)).^2);

        d_end(idxA,idxB)   = sqrt(sum(coorEnd(idxA,:) - coorEnd(idxB,:)).^2);
        
    end
end

%When the distances between starts and ends of a pair of arrows are both
%less than K they are considered duplicates
K = 11;
duplicates = double(d_start < K & d_end < K);
%surf(duplicates), view(2), axis tight;

%Identifies true duplicates (does not include "duplicates" that are the same arrow twice) 
list_remove = [];
for idx=1:noarrows,
    
    index = setdiff(find(duplicates(idx,:)),idx);
    
    if ~isempty(index),
        
        %Location of the duplicate
        set_index = [idx;index(:)];
        
        %Orders p-values for each duplicate
        [p_set,p_set_index] = sort(pv(set_index));        
        
        %Adds to list_remove all of the duplicates but the one with the
        %highest p-value
        list_remove = [list_remove;set_index(p_set_index(2:end))];
        
    end
    
end

for idx=1:noarrows,
    d(idx) = sqrt(sum((coorStart(idx,:)-coorEnd(idx,:)).^2));
end

list_remove = [list_remove;find(d(:) < K)];

ind = setdiff(p_sorted_index,unique(list_remove));
coorStart = coorStart(ind,:);
coorEnd = coorEnd(ind,:);
pv = pv(ind);

[p_sorted,p_sorted_index] = sort(pv);

ind = p_sorted_index(p_sorted_index(end:-1:1));
coorStart = coorStart(ind,:);
coorEnd = coorEnd(ind,:);
pv = pv(ind);

%Transforms coordinates (why?)
coorStart(:,3) = coorStart(:,3) - 6;
coorEnd(:,3) = coorEnd(:,3) - 6;
coorStart(:,1) = coorStart(:,1) - 3;
coorEnd(:,1) = coorEnd(:,1) - 3;


%Make the model coarser:
cortexcoarser = coarserModel(brainStruct.cortex, 10000);

%Use the coarse model and make it smoother:
origin = [0 20 40];
smoothrad = 25;
mult = 0.5;

%(See also |smoothModel| for further information on the arguments used)
[cortexsmoothed] = smoothModel(cortexcoarser, smoothrad, origin, mult);

%Compute the convex hull:
cortex_convex = hullModel(cortexsmoothed);
%This deprives the brain model of the sulci

brainStruct.cortex = cortex_convex;

ArSzLt = [1 2];
id = pv == 0;
pv(id) = 1e-30;
pv = -log10(pv);
%Plots brain and arrows
projectedArrows = plotArrows(brainStruct, coorStart, coorEnd, pv, ArSzLt);
%Plots balls for electrodes
plotBalls(coorStart, 'r', 1.5); plotBalls(coorEnd, 'r', 1.5); 

load coord.mat
for idx=1:length(coord),
   coord{idx}(:,1) = coord{idx}(:,1) - 3;
%   plotBalls(coord{idx}, 'k', 0.8) 
end

%export_fig('arrows','-png','-cmyk','-r100',gcf);



%set(gcf,'PaperPosition',[0,0,12,6]);
%set(gcf,'PaperSize',[12,6]);
%print('-r600','-dpng','arrows.png');        



