if strcmp(viztype, '2D') || strcmp(viztype, '2d')
    param.brain_type = 'talairach';

    % Do 2D stuff

    % Start activateBrain code (used to find bubble/electrode coordinates)    
    opengl neverselect
    
    %Load talairach brain model for electrode projection so the projected electrodes will match the 2d image of the talairach brain 
    load ('pial_talairach.mat', 'cortex');
    
    %Make the model coarser:
    cortexcoarser = coarserModel(cortex, 10000);

    %Use the coarse model and make it smoother:
    origin = [0 20 40];
    smoothrad = 25;
    mult = 0.5;
    
    cortex_convex = hullModel(cortexcoarser);
    %This deprives the brain model of the sulci
    
    eLectrode.Coords = input('Enter the variable containing the coordinates for the unprojected electrodes (type ''help'' for help): ');
    while isa(eLectrode.Coords, 'char')
        fprintf('The 3D coordinates of the electrode location should be contained in an M by 3 array, where M is the number of electrodes\nEach row should contain a set of coordinates for a single electrode.\nFor an example, type load(''MNI_brain.mat'', ''tala''); into the console and view tala.electrodes in the variable editor.\n');
        eLectrode.Coords = input('Enter the variable containing the coordinates for the unprojected electrodes (type ''help'' for help): ');            
    end
    noActivations = zeros(size(eLectrode.Coords, 1), 1);
    
    eLectrode.Acts = input('Enter the variable containing the activations for the electrodes (if there are no activations, type noActivations, type ''help'' for help): ');
    while isa(eLectrode.Acts, 'char')
        fprintf('The activations for the electrodes should be contained in an M by 1 array, where M is the number of electrodes\nEach row should contain an activation value.\nFor an example, type load(''MNI_brain.mat'', ''tala''); into the console and view tala.activations in the variable editor.\n');
        eLectrode.Acts = input('Enter the variable containing the coordinates for the unprojected electrodes (if there are no activations, type noActivations, type ''help'' for help): ');            
    end
    
    tala.electrodes = eLectrode.Coords;
    tala.activations = eLectrode.Acts;

    %Projecting the electrodes
    normdist = 60;
    [ tala ] = projectElectrodes( cortex_convex, tala, normdist);
    % End activateBrain code

    fprintf('See Data Visualization Package/Functions/config.m for an explanation of the configuration class.\n')
    default = input('Use default configuration? (1 | 0): ');
    
    if ~default
        userConfig = input('Enter your configuration variable: ');
        c = userConfig;
        nodes = input('Please enter the list of nodes: ');
        links = input('Please enter the list of links: ');
    else
        c = config;
        c.x = 1;
        c.y = 2;
        c.size = 3;
        c.nodesizemin = 2;
        c.nodesizemax = 12;
        c.nodecolor = 'rgba(0, 0, 0, 0.2)';
        c.fixed = 1;
        c.drawlinks = 0;
        c.image = 1;
        c.imageheight = 400;
        c.imagewidth = 587;
    end
    
    if default
        param.electrodes_pos = input('Are the electrodes on the left or right side of the brain? (''left'' | ''right'') ');
        
        if strcmp(param.electrodes_pos, 'left')
                copyfile('MATLAB/DVP & activateBrain/talairachleft.png');
                c.imagepath = 'talairachleft.png';
                c.xMin = 101;
                c.xMax = -67;
                c.yMin = -42;
                c.yMax = 75;
                for i = 1:length(tala.trielectrodes)
                    nodes{i} = {-(tala.trielectrodes(i,2)), tala.trielectrodes(i,3), tala.activations(i)};
                end
        elseif strcmp(param.electrodes_pos, 'right')
                copyfile('MATLAB/DVP & activateBrain/talairachright.png');
                c.imagepath = 'talairachright.png';
                c.xMin = 67;
                c.xMax = -101;
                c.yMin = -42;
                c.yMax = 75;
                for i = 1:length(tala.trielectrodes)
                    nodes{i} = {tala.trielectrodes(i,2), tala.trielectrodes(i,3), tala.activations(i)};
                end
        end
        
        links = [];
    end

    fprintf('Generating visualization...\n');
    drawbubbles(nodes, links, c, 'openhtml');
    fprintf('Done.\n');
            
% Do 3D stuff
elseif strcmp(viztype, '3D') || strcmp(viztype, '3d')
    plot_brain;
end